pub fn auto_sniff(path: &Path) -> Result<SniffedRunner>Expand description
Resolve path to a single weight file, then sniff the runner.
pub fn auto_sniff(path: &Path) -> Result<SniffedRunner>Resolve path to a single weight file, then sniff the runner.